# kash-media-kit

See the main [kash](https://github.com/jlevy/kash) repo for general instructions.

To run media kit, ensure you have uv set up then:

```shell
# Install all deps and run tests:
make
# Run kash with media kit actions enabled:
uv run kash
```

* * *

*This project was built from
[simple-modern-uv](https://github.com/jlevy/simple-modern-uv).*
